@@ -40,6 +40,13 @@
 #endif
 #define WSPTR(s) ((s)->ws)
 
+#ifdef VPFX
+# define VEVENT(a) VPFX(a)
+#else
+/* For compatibility with varnish prior to 6.2 */
+# define VEVENT(a) a
+#endif
+
 #include "vmod-binlog.h"
 #include "pack.h"
 #include "pthread.h"
@@ -155,7 +162,7 @@ packerror(const char *fmt, ...)
 }
 
 int
-vmod_binlog_event(VRT_CTX, struct vmod_priv *priv, enum vcl_event_e e)
+VEVENT(binlog_event)(VRT_CTX, struct vmod_priv *priv, enum vcl_event_e e)
 {
 	if (e == VCL_EVENT_LOAD) {
 		struct binlog_config *conf = calloc(1, sizeof(*conf));
